TaskMessage

Enum TaskMessage 

pub enum TaskMessage<R, Route> {
    Complete {
        result: R,
        reply_to: Route,
    },
    Cancel {
        reply_to: Route,
    },
}
Commands accepted by a Task.

Variants



Complete

Complete with one owned result and its typed recipient.

Fields

result: R

Owned terminal result.

reply_to: Route

Recipient for the terminal fact.



Cancel

Cancel before completion and report to a typed recipient.

Fields

reply_to: Route

Recipient for the cancellation fact.