pub enum TerminationObservation {
Requested,
Observing,
Observed,
Cancelled,
Rejected {
operation: ObservationOperation,
reason: ObservationRejection,
},
}Expand description
Complete consumption phase of one exact terminal observation.
Variants
Requested
The exact request is retained for emission or awaits its first response.
Observing
The configured peer’s terminal report has not been accepted.
Observed
One matching terminal report was accepted and cannot be accepted again.
Cancelled
The exact observation relationship was cancelled before termination.
Rejected
The exact observation operation was rejected.