EstablishedTerminationTarget

Struct EstablishedTerminationTarget 

pub struct EstablishedTerminationTarget<B: Behavior, P>{ /* private fields */ }
Exact-incarnation termination observation policy and its one current value.

Implementations

Source

impl<B, P> EstablishedTerminationTarget<B, P>

pub fn take_cancellation(&mut self) -> Option<CancelObservation<P>>

Transfer the one current grant into a typed cancellation request. The caller must return that request in its owning Actions lane.

pub fn into_rejected_observe( self, ) -> Result<(ObserveEstablished<P>, ObservationRejection), Self>

Recover the whole rejected start or return every current target value.

pub fn into_rejected_cancel( self, ) -> Result<(CancelObservation<P>, ObservationRejection), Self>

Recover the whole rejected cancellation or return the current target.