pub type ShutdownEvent<E> = EventLayer<ShutdownRequested, E>;Expand description
Internal event sum of a behavior that supports graceful shutdown.
Aliased Type
pub enum ShutdownEvent<E> {
Owned(ShutdownRequested),
Inner(E),
}pub type ShutdownEvent<E> = EventLayer<ShutdownRequested, E>;Internal event sum of a behavior that supports graceful shutdown.
pub enum ShutdownEvent<E> {
Owned(ShutdownRequested),
Inner(E),
}