pub enum ShutdownCoordinatorError<E, A: Address, P> {
Behavior(E),
ChildRejected {
child: CreationId,
reason: ChildShutdownRejection,
},
UnexpectedChildStopped(ChildStopped<A>),
UnexpectedChildRejection {
child: CreationId,
reason: ChildShutdownRejection,
},
PlanAlreadyInstalled(P),
}Expand description
Controlled coordinated-shutdown failure.
Variants
Behavior(E)
ChildRejected
UnexpectedChildStopped(ChildStopped<A>)
A child-stop fact did not name a child awaited by the current phase.
UnexpectedChildRejection
A child-shutdown rejection did not name a child awaited by the current phase.
PlanAlreadyInstalled(P)
A plan was supplied after one had already been installed or completed.