pub enum TaskMessage<R, Route> {
Complete {
result: R,
reply_to: Route,
},
Cancel {
reply_to: Route,
},
}Expand description
Commands accepted by a Task.
Variants
Complete
Complete with one owned result and its typed recipient.
Cancel
Cancel before completion and report to a typed recipient.
Fields

reply_to: RouteRecipient for the cancellation fact.