pub struct EstablishedTerminationTarget<B: Behavior, P>{ /* private fields */ }Expand description
Exact-incarnation termination observation policy and its one current value.
Implementations
Sourceimpl<B, P> EstablishedTerminationTarget<B, P>
impl<B, P> EstablishedTerminationTarget<B, P>
Sourcepub fn take_cancellation(&mut self) -> Option<CancelObservation<P>>
pub fn take_cancellation(&mut self) -> Option<CancelObservation<P>>
Transfer the one current grant into a typed cancellation request. The caller must return that request in its owning Actions lane.
Sourcepub fn into_rejected_observe(
self,
) -> Result<(ObserveEstablished<P>, ObservationRejection), Self>
pub fn into_rejected_observe( self, ) -> Result<(ObserveEstablished<P>, ObservationRejection), Self>
Recover the whole rejected start or return every current target value.
Sourcepub fn into_rejected_cancel(
self,
) -> Result<(CancelObservation<P>, ObservationRejection), Self>
pub fn into_rejected_cancel( self, ) -> Result<(CancelObservation<P>, ObservationRejection), Self>
Recover the whole rejected cancellation or return the current target.